@@ -25,10 +25,11 @@ class General:
         self.ene = ['g1', 1, 1E-09, 2.15E-06, 20.0]
         self.nfg = self.ene[0]
         self.div = None
+        self.additional_lines = []
         pass
 
     def _compile_title(self, file):
-        file.write(f'set title \"{self.acelib}\" \n')
+        file.write(f'set title \"{self.title}\" \n')
 
     def _compile_acelib(self, file):
         file.write(f'set acelib \"{self.acelib}\" \n')
@@ -93,7 +94,7 @@ class General:
         if self.src is None:
             pass
         elif self.src == "n":
-            file.write(f'set src {self.src} \n')
+            file.write(f'src {self.src} \n')
         else:
             logger.error(f'Src attribute possible values must be "n" or None')
             raise AttributeError(f'Src attribute possible values must be "n" or None')
@@ -129,9 +130,13 @@ class General:
             pass
         else:
             for key in self.div.keys():
-                file.write(f'div {key} sep {self.div[key][0]} '
+                file.write(f'div {key} sep {int(self.div[key][0])} '
                            f'subr {int(self.div[key][1])} {self.div[key][2]} {self.div[key][3]} \n')
 
+    def _compile_additional_lines(self, file):
+        for line in self.additional_lines:
+            file.write(f'{line} \n')
+
     def compile(self, filename):
         with open(filename, 'w') as file:
             self._compile_title(file)
@@ -165,6 +170,8 @@ class General:
             file.write('\n')
             self._compile_div(file)
             file.write('\n')
+            self._compile_additional_lines(file)
+            file.write('\n')
 
 
 if __name__ == '__main__':
